@@ -12,7 +12,6 @@ import sys
 
 from .complete import CompleteCommand
 from .help import HelpAction, HelpCommand
-from .interactive import InteractiveApp
 
 # Make sure the cliff library has a logging handler
 # in case the app developer doesn't set up logging.
@@ -65,7 +64,7 @@ class App(object):
 
     def __init__(self, description, version, command_manager,
                  stdin=None, stdout=None, stderr=None,
-                 interactive_app_factory=InteractiveApp,
+                 interactive_app_factory=None,
                  deferred_help=False):
         """Initialize the application.
         """
@@ -210,7 +209,7 @@ class App(object):
         """
         if self.deferred_help and self.options.deferred_help:
             action = HelpAction(None, None, default=self)
-            action(self.parser, self.parser, None, None)
+            action(self.parser, self.options, None, None)
 
     def run(self, argv):
         """Equivalent to the main program for the application.
@@ -275,6 +274,11 @@ class App(object):
         return
 
     def interact(self):
+        # Defer importing .interactive as cmd2 is a slow import
+        from .interactive import InteractiveApp
+
+        if self.interactive_app_factory is None:
+            self.interactive_app_factory = InteractiveApp
         self.interpreter = self.interactive_app_factory(self,
                                                         self.command_manager,
                                                         self.stdin,
